@@ -1,14 +1,14 @@
 # Copyrights 2006-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 
 use warnings;
 use strict;
 
 package XML::Compile;
 use vars '$VERSION';
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
@@ -72,40 +72,40 @@ $parser->line_numbers(1);
 $parser->no_network(1);
 
 sub dataToXML($)
-{   my ($self, $thing) = @_;
-    defined $thing
+{   my ($thing, $raw) = @_;
+    defined $raw
         or return;
 
     my ($xml, %details);
-    if(ref $thing && UNIVERSAL::isa($thing, 'XML::LibXML::Node'))
-    {   ($xml, %details) = $self->_parsedNode($thing);
+    if(ref $raw && UNIVERSAL::isa($raw, 'XML::LibXML::Node'))
+    {   ($xml, %details) = $thing->_parsedNode($raw);
     }
-    elsif(ref $thing eq 'SCALAR')   # XML string as ref
-    {   ($xml, %details) = $self->_parseScalar($thing);
+    elsif(ref $raw eq 'SCALAR')   # XML string as ref
+    {   ($xml, %details) = $thing->_parseScalar($raw);
     }
-    elsif(ref $thing eq 'GLOB')     # from file-handle
-    {   ($xml, %details) = $self->_parseFileHandle($thing);
+    elsif(ref $raw eq 'GLOB')     # from file-handle
+    {   ($xml, %details) = $thing->_parseFileHandle($raw);
     }
-    elsif($thing =~ m/^\s*\</)      # XML starts with '<', rare for files
-    {   ($xml, %details) = $self->_parseScalar(\$thing);
+    elsif($raw =~ m/^\s*\</)      # XML starts with '<', rare for files
+    {   ($xml, %details) = $thing->_parseScalar(\$raw);
     }
-    elsif(my $known = $self->knownNamespace($thing))
-    {   my $fn  = $self->findSchemaFile($known)
+    elsif(my $known = $thing->knownNamespace($raw))
+    {   my $fn  = $thing->findSchemaFile($known)
             or error __x"cannot find pre-installed name-space file named {path} for {name}"
-                 , path => $known, name => $thing;
+                 , path => $known, name => $raw;
 
-        ($xml, %details) = $self->_parseFile($fn);
-        $details{source} = "known namespace $thing";
+        ($xml, %details) = $thing->_parseFile($fn);
+        $details{source} = "known namespace $raw";
     }
-    elsif(my $fn = $self->findSchemaFile($thing))
-    {   ($xml, %details) = $self->_parseFile($fn);
-        $details{source} = "filename in schema-dir $thing";
+    elsif(my $fn = $thing->findSchemaFile($raw))
+    {   ($xml, %details) = $thing->_parseFile($fn);
+        $details{source} = "filename in schema-dir $raw";
     }
-    elsif(-f $thing)
-    {   ($xml, %details) = $self->_parseFile($thing);
+    elsif(-f $raw)
+    {   ($xml, %details) = $thing->_parseFile($raw);
     }
     else
-    {   my $data = "$thing";
+    {   my $data = "$raw";
         $data = substr($data, 0, 39) . '...' if length($data) > 40;
         error __x"don't known how to interpret XML data\n   {data}"
            , data => $data;
@@ -195,7 +195,7 @@ sub knownNamespace($;@)
 
 
 sub findSchemaFile($)
-{   my ($self, $fn) = @_;
+{   my ($thing, $fn) = @_;
 
     return (-f $fn ? $fn : undef)
         if File::Spec->file_name_is_absolute($fn);
