@@ -1,11 +1,11 @@
 # Copyrights 2006-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use base 'XML::Compile::Translate';
 
@@ -204,7 +204,7 @@ sub makeChoice($@)
                   $@->reportAll if $starter != keys %$values;
                   next;
               }
-              elsif($@) {$@->reportAll}
+              elsif(defined $@) {$@->reportAll}
 
               return @d;
           }
@@ -220,7 +220,7 @@ sub makeChoice($@)
               {   $@->reportAll if $starter != keys %$values;
                   next;
               }
-              elsif($@) {$@->reportAll}
+              elsif(defined $@) {$@->reportAll}
               return @d;
           }
 
