@@ -1,16 +1,13 @@
 # Copyrights 2006-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 use warnings;
 use strict;
 
-use lib '../XMLCompile/lib'  # test environment at home
-      , '../XMLTester/lib';
-
 package TestTools;
 use vars '$VERSION';
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 use base 'Exporter';
 
@@ -29,11 +26,11 @@ our @EXPORT = qw/
  $SchemaNSi
  $dump_pkg
  test_rw
+ error_r
+ error_w
  /;
 
 our $TestNS    = 'http://test-types';
-set_default_namespace $TestNS;
-
 our $SchemaNS  = SCHEMA2001;
 our $SchemaNSi = SCHEMA2001i;
 our $dump_pkg  = 't::dump';
@@ -75,4 +72,16 @@ sub test_rw($$$$;$$)
     compare_xml($tree, $expect || $xml);
 }
 
+sub error_r($$$)
+{   my ($schema, $test, $xml) = @_;
+    my $type = $test =~ m/\{/ ? $test : "{$TestNS}$test";
+    reader_error($schema, $type, $xml);
+}
+
+sub error_w($$$)
+{   my ($schema, $test, $data) = @_;
+    my $type = $test =~ m/\{/ ? $test : "{$TestNS}$test";
+    writer_error($schema, $type, $data);
+}
+
 1;
